/* ESP32_DS18B20
 *  
 * Hőmérő projekt két, vagy több DS18B20 digitális hőmérő szenzorral
 * mérjük a hőmérsékletet és kiíratjuk a soros porton
 * A program az alábbi könyvtárakat igényli:
 * DallasTemperature 3.8.0 (Miles Burton):
 * https://github.com/milesburton/Arduino-Temperature-Control-Library
 * OneWire 2.3.4 (Paul Stoffregen): https://github.com/PaulStoffregen/OneWire
 * Megjegyzés: az OneWire könyvtár újabb verziói ESP32-vel
 * nem működnek helyesen. A 2.3.4, illetve a korábbi verziók pedig 
 * működnek de csak warning üzenetekkel fordulnak le. 
 * 
 * A programot az Arduino IDE 1.8.16 és ESP32 2.0.0 verziójával próbáltuk ki
 * DOIT ESP32 DEVKIT V1 kártyával, Windows 10 64-bit környezetben
 */

#include <OneWire.h>                                // OneWire 2.3.4 (Paul Stoffregen)
#include <DallasTemperature.h>                      // DallasTemperature 3.8.0 (Miles Burton)

#define ONEWIREPIN 15                               // Az 1-wire busz a D15 lábra csatlakozik 
int numberOfDevices;                                // Az 1-wire buszra kötött hőmérők száma

OneWire oneWire(ONEWIREPIN);                        // 1-wire busz példányosítása
DallasTemperature sensors(&oneWire);                // hőmérő(k) példányosítása

void setup() {
  Serial.begin(115200);  
  sensors.begin();                                  // a szenzor(ok) inicializálása
  numberOfDevices = sensors.getDeviceCount();       // a szenzorok összeszámlálása
}

void loop() {
  sensors.requestTemperatures();                    // Hőmérsékletmérés parancs kiküldése
  for(int i=0;i<numberOfDevices; i++){
    float tempC = sensors.getTempCByIndex(i);       // Az i. hőmérő kiolvasása
    Serial.print(i);                                // Az eredmény kiíratása
    Serial.print(". hőmérő: ");
    Serial.print(tempC,1);
    Serial.println("°C");
  }
  delay(5000);
}
