/* ESP32_PIR_sensor

   Ebben a projektben egy HC-SR501 PIR szenzorral
   keltünk külső megszakításokat (felfutó élre
   kell érzékenyíteni a bemenetet). Megszakítás 
   hatására a program előre megadott ideig végez 
   valamilyen tevékenységet (itt a LED világít)
   Az időzítéshez a millis() függvényt használjuk.
   A programban 5 másodperces időzítést állítottunk be.
   A PIR szenzor konfigurációja: Single mód, 3 sec, 3 m

   Bekötés:
   LED (anód) -- GPIO 2
   LED (katód)-- GND-re egy 220R ellenálláson keresztül 
   PIR sensor -- GPIO 13
   VCC        -- VIN (+5V)
   GND        -- GND

   The original program was written by Rui Santos
   Complete project details at https://randomnerdtutorials.com
   Modified by. István Cserny
   
   Tested with Arduino IDE 1.8.16 and ESP32 2.0.0
   DOIT ESP32 DEVKIT V1 board, Windows 10 64-bit system
 */

#define timeSeconds 5

// Set GPIOs for LED and PIR Motion Sensor
const int led = 2;
const int motionSensor = 13;

// Timer: Auxiliary variables
unsigned long now;
unsigned long lastTrigger = 0;
volatile boolean startTimer = false;

// Checks if motion was detected, sets LED HIGH and starts a timer
void IRAM_ATTR detectsMovement() {
  digitalWrite(led, HIGH);      // Set alarm signal
  startTimer = true;            // Set timer flag
  lastTrigger = millis();       // Notice time of event
}

void setup() {
  // PIR Motion Sensor mode INPUT_PULLUP
  pinMode(motionSensor, INPUT_PULLUP);
  // Set motionSensor pin as interrupt, assign interrupt function and set RISING mode
  attachInterrupt(motionSensor, detectsMovement, RISING);
  // Set LED to LOW
  pinMode(led, OUTPUT);
  digitalWrite(led, LOW);
}

void loop() {
  // Current time
  now = millis();
  // Turn off the LED after the number of seconds defined in the timeSeconds variable
  if (startTimer && (now - lastTrigger > (timeSeconds * 1000))) {
    digitalWrite(led, LOW);
    startTimer = false;
  }
  delay(50);
}
