/* ESP32_button_debounce

   Nyomógomb pergésmentesítése mintavételezéssel,
   időzítővel keltett periodikus megszakításokban.
   A szoftveresen pergésmentesített BOOT nyomógombbal
   a beépített LED-et kapcsolgatjuk.
*/

#include <Arduino.h>
#define BUTTON      0                            // Beépített nyomógomb (GPIO 0)
uint8_t button_state = 1;                        // Nyomógomb állapotjelző
volatile boolean keypress = false;               // Gomblenyomás eseményjelző
boolean led_state = false;                       // LED állapot tárolója
hw_timer_t* timer = NULL;                        // Timer "fogantyú"
portMUX_TYPE timerMux = portMUX_INITIALIZER_UNLOCKED;

void IRAM_ATTR onTime() {                        // Megszakítás kiszolgálás
  button_state = (button_state << 1) | digitalRead(BUTTON);
  if ((!keypress) && ((button_state & 3) == 2)){ // 1 -> 0 átmenet lenyomást jelez 
    portENTER_CRITICAL_ISR(&timerMux);           // Kritikus szekcióba lépünk
    keypress = true;                             // keypress írását védjük
    portEXIT_CRITICAL_ISR(&timerMux);            // Kritikus szekció vége
  }
}

void setup() {
  pinMode(LED_BUILTIN, OUTPUT);                  // LED kimenet konfigurálása
  digitalWrite(LED_BUILTIN, LOW);                // és alaphelyzetbe állítása
  pinMode(BUTTON, INPUT_PULLUP);                 // Nyomógomb bemenet aktiválás
  timer = timerBegin(0, 80, true);               // Timer0, előosztó=80, felfutó élre számlál
  timerAttachInterrupt(timer, &onTime, true);    // Kiszolgáló függvény csatolása
  timerAlarmWrite(timer, 20000, true);           // Ébresztés 20 milliszekundumonként
  timerAlarmEnable(timer);                       // Ébresztés engedélyezése
}

void loop() {
  if (keypress) {                                // lenyomás esemény esetén
    portENTER_CRITICAL_ISR(&timerMux);           // kritikus szekció kezdete
    keypress = false;                            // jelző törlése
    portEXIT_CRITICAL_ISR(&timerMux);            // kritikus szekció vége
    led_state = !led_state;                      // LED állapot negálás
    digitalWrite(LED_BUILTIN, led_state);        // LED állapot aktualizálása
  }
}
